@@ -10,10 +10,10 @@
 # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations under the License.
 #
-from typing import Any, Optional
+from typing import Any
 
 from jdmn.feel.lib.FEELLib import FEELLib
-from jdmn.feel.lib.Types import NUMBER, BOOLEAN, DATE, TIME, DATE_TIME, DURATION, LIST, LONG, STRING
+from jdmn.feel.lib.Types import DECIMAL, BOOLEAN, DATE, TIME, DATE_TIME, DURATION, LIST, INTEGER, STRING, CONTEXT, RANGE
 from jdmn.feel.lib.type.bool.DefaultBooleanType import DefaultBooleanType
 from jdmn.feel.lib.type.context.DefaultContextType import DefaultContextType
 from jdmn.feel.lib.type.function.DefaultFunctionType import DefaultFunctionType
@@ -25,9 +25,7 @@ from jdmn.feel.lib.type.time.DefaultDateTimeType import DefaultDateTimeType
 from jdmn.feel.lib.type.time.DefaultDateType import DefaultDateType
 from jdmn.feel.lib.type.time.DefaultDurationType import DefaultDurationType
 from jdmn.feel.lib.type.time.DefaultTimeType import DefaultTimeType
-from jdmn.runtime.Context import Context
 from jdmn.runtime.LazyEval import LazyEval
-from jdmn.runtime.Range import Range
 from jdmn.runtime.listener.EventListener import EventListener
 from jdmn.runtime.listener.Rule import Rule
 
@@ -60,7 +58,7 @@ class BaseFEELLib(FEELLib):
             self.logError(message, e)
             return False
 
-    def numericValue(self, value: NUMBER) -> NUMBER:
+    def numericValue(self, value: DECIMAL) -> DECIMAL:
         try:
             return self.numericType.numericValue(value)
         except Exception as e:
@@ -68,7 +66,7 @@ class BaseFEELLib(FEELLib):
             self.logError(message, e)
             return None
 
-    def numericIs(self, first: NUMBER, second: NUMBER) -> BOOLEAN:
+    def numericIs(self, first: DECIMAL, second: DECIMAL) -> BOOLEAN:
         try:
             return self.numericType.numericIs(first, second)
         except Exception as e:
@@ -76,7 +74,7 @@ class BaseFEELLib(FEELLib):
             self.logError(message, e)
             return None
 
-    def numericEqual(self, first: NUMBER, second: NUMBER) -> BOOLEAN:
+    def numericEqual(self, first: DECIMAL, second: DECIMAL) -> BOOLEAN:
         try:
             return self.numericType.numericEqual(first, second)
         except Exception as e:
@@ -84,7 +82,7 @@ class BaseFEELLib(FEELLib):
             self.logError(message, e)
             return None
 
-    def numericNotEqual(self, first: NUMBER, second: NUMBER) -> BOOLEAN:
+    def numericNotEqual(self, first: DECIMAL, second: DECIMAL) -> BOOLEAN:
         try:
             return self.numericType.numericNotEqual(first, second)
         except Exception as e:
@@ -92,7 +90,7 @@ class BaseFEELLib(FEELLib):
             self.logError(message, e)
             return None
 
-    def numericLessThan(self, first: NUMBER, second: NUMBER) -> BOOLEAN:
+    def numericLessThan(self, first: DECIMAL, second: DECIMAL) -> BOOLEAN:
         try:
             return self.numericType.numericLessThan(first, second)
         except Exception as e:
@@ -100,7 +98,7 @@ class BaseFEELLib(FEELLib):
             self.logError(message, e)
             return None
 
-    def numericGreaterThan(self, first: NUMBER, second: NUMBER) -> BOOLEAN:
+    def numericGreaterThan(self, first: DECIMAL, second: DECIMAL) -> BOOLEAN:
         try:
             return self.numericType.numericGreaterThan(first, second)
         except Exception as e:
@@ -108,7 +106,7 @@ class BaseFEELLib(FEELLib):
             self.logError(message, e)
             return None
 
-    def numericLessEqualThan(self, first: NUMBER, second: NUMBER) -> BOOLEAN:
+    def numericLessEqualThan(self, first: DECIMAL, second: DECIMAL) -> BOOLEAN:
         try:
             return self.numericType.numericLessEqualThan(first, second)
         except Exception as e:
@@ -116,7 +114,7 @@ class BaseFEELLib(FEELLib):
             self.logError(message, e)
             return None
 
-    def numericGreaterEqualThan(self, first: NUMBER, second: NUMBER) -> BOOLEAN:
+    def numericGreaterEqualThan(self, first: DECIMAL, second: DECIMAL) -> BOOLEAN:
         try:
             return self.numericType.numericGreaterEqualThan(first, second)
         except Exception as e:
@@ -124,7 +122,7 @@ class BaseFEELLib(FEELLib):
             self.logError(message, e)
             return None
 
-    def numericAdd(self, first: NUMBER, second: NUMBER) -> NUMBER:
+    def numericAdd(self, first: DECIMAL, second: DECIMAL) -> DECIMAL:
         try:
             return self.numericType.numericAdd(first, second)
         except Exception as e:
@@ -132,7 +130,7 @@ class BaseFEELLib(FEELLib):
             self.logError(message, e)
             return None
 
-    def numericSubtract(self, first: NUMBER, second: NUMBER) -> NUMBER:
+    def numericSubtract(self, first: DECIMAL, second: DECIMAL) -> DECIMAL:
         try:
             return self.numericType.numericSubtract(first, second)
         except Exception as e:
@@ -140,7 +138,7 @@ class BaseFEELLib(FEELLib):
             self.logError(message, e)
             return None
 
-    def numericMultiply(self, first: NUMBER, second: NUMBER) -> NUMBER:
+    def numericMultiply(self, first: DECIMAL, second: DECIMAL) -> DECIMAL:
         try:
             return self.numericType.numericMultiply(first, second)
         except Exception as e:
@@ -148,7 +146,7 @@ class BaseFEELLib(FEELLib):
             self.logError(message, e)
             return None
 
-    def numericDivide(self, first: NUMBER, second: NUMBER) -> NUMBER:
+    def numericDivide(self, first: DECIMAL, second: DECIMAL) -> DECIMAL:
         try:
             return self.numericType.numericDivide(first, second)
         except Exception as e:
@@ -156,7 +154,7 @@ class BaseFEELLib(FEELLib):
             self.logError(message, e)
             return None
 
-    def numericUnaryMinus(self, first: NUMBER) -> NUMBER:
+    def numericUnaryMinus(self, first: DECIMAL) -> DECIMAL:
         try:
             return self.numericType.numericUnaryMinus(first)
         except Exception as e:
@@ -164,7 +162,7 @@ class BaseFEELLib(FEELLib):
             self.logError(message, e)
             return None
 
-    def numericExponentiation(self, first: NUMBER, second: NUMBER) -> NUMBER:
+    def numericExponentiation(self, first: DECIMAL, second: DECIMAL) -> DECIMAL:
         try:
             return self.numericType.numericExponentiation(first, second)
         except Exception as e:
@@ -349,7 +347,7 @@ class BaseFEELLib(FEELLib):
             self.logError(message, e)
             return False
 
-    def dateValue(self, date: DATE) -> LONG:
+    def dateValue(self, date: DATE) -> INTEGER:
         try:
             return self.dateType.dateValue(date)
         except Exception as e:
@@ -450,7 +448,7 @@ class BaseFEELLib(FEELLib):
             self.logError(message, e)
             return False
 
-    def timeValue(self, time: TIME) -> LONG:
+    def timeValue(self, time: TIME) -> INTEGER:
         try:
             return self.timeType.timeValue(time)
         except Exception as e:
@@ -549,7 +547,7 @@ class BaseFEELLib(FEELLib):
             self.logError(message, e)
             return False
 
-    def dateTimeValue(self, dateTime: DATE_TIME) -> LONG:
+    def dateTimeValue(self, dateTime: DATE_TIME) -> INTEGER:
         try:
             return self.dateTimeType.dateTimeValue(dateTime)
         except Exception as e:
@@ -615,9 +613,9 @@ class BaseFEELLib(FEELLib):
 
     def dateTimeSubtract(self, first: DATE_TIME, second: DATE_TIME) -> DURATION:
         try:
-            if (self.isDate(first)):
+            if self.isDate(first):
                 first = self.toDateTime(first)
-            if (self.isDate(second)):
+            if self.isDate(second):
                 second = self.toDateTime(second)
 
             return self.dateTimeType.dateTimeSubtract(first, second)
@@ -677,7 +675,7 @@ class BaseFEELLib(FEELLib):
             self.logError(message, e)
             return None
 
-    def durationValue(self, duration: DURATION) -> LONG:
+    def durationValue(self, duration: DURATION) -> INTEGER:
         try:
             return self.durationType.durationValue(duration)
         except Exception as e:
@@ -749,7 +747,7 @@ class BaseFEELLib(FEELLib):
             self.logError(message, e)
             return None
 
-    def durationDivide(self, first: DURATION, second: DURATION) -> NUMBER:
+    def durationDivide(self, first: DURATION, second: DURATION) -> DECIMAL:
         try:
             return self.durationType.durationDivide(first, second)
         except Exception as e:
@@ -757,7 +755,7 @@ class BaseFEELLib(FEELLib):
             self.logError(message, e)
             return None
 
-    def durationMultiplyNumber(self, first: DURATION, second: NUMBER) -> DURATION:
+    def durationMultiplyNumber(self, first: DURATION, second: DECIMAL) -> DURATION:
         try:
             return self.durationType.durationMultiplyNumber(first, second)
         except Exception as e:
@@ -765,7 +763,7 @@ class BaseFEELLib(FEELLib):
             self.logError(message, e)
             return None
 
-    def durationDivideNumber(self, first: DURATION, second: NUMBER) -> DURATION:
+    def durationDivideNumber(self, first: DURATION, second: DECIMAL) -> DURATION:
         try:
             return self.durationType.durationDivideNumber(first, second)
         except Exception as e:
@@ -827,7 +825,7 @@ class BaseFEELLib(FEELLib):
             self.logError(message, e)
             return False
 
-    def contextValue(self, value: Context) -> Context:
+    def contextValue(self, value: CONTEXT) -> CONTEXT:
         try:
             return self.contextType.contextValue(value)
         except Exception as e:
@@ -835,7 +833,7 @@ class BaseFEELLib(FEELLib):
             self.logError(message, e)
             return None
 
-    def contextIs(self, c1: Any, c2: Any) -> BOOLEAN:
+    def contextIs(self, c1: CONTEXT, c2: CONTEXT) -> BOOLEAN:
         try:
             return self.contextType.contextIs(c1, c2)
         except Exception as e:
@@ -843,7 +841,7 @@ class BaseFEELLib(FEELLib):
             self.logError(message, e)
             return None
 
-    def contextEqual(self, c1: Any, c2: Any) -> BOOLEAN:
+    def contextEqual(self, c1: CONTEXT, c2: CONTEXT) -> BOOLEAN:
         try:
             return self.contextType.contextEqual(c1, c2)
         except Exception as e:
@@ -851,7 +849,7 @@ class BaseFEELLib(FEELLib):
             self.logError(message, e)
             return None
 
-    def contextNotEqual(self, c1: Any, c2: Any) -> BOOLEAN:
+    def contextNotEqual(self, c1: CONTEXT, c2: CONTEXT) -> BOOLEAN:
         try:
             return self.contextType.contextNotEqual(c1, c2)
         except Exception as e:
@@ -862,7 +860,7 @@ class BaseFEELLib(FEELLib):
     #
     # Context functions
     #
-    def getEntries(self, m: Any) -> LIST:
+    def getEntries(self, m: CONTEXT) -> LIST:
         try:
             return self.contextType.getEntries(m)
         except Exception as e:
@@ -870,7 +868,7 @@ class BaseFEELLib(FEELLib):
             self.logError(message, e)
             return None
 
-    def getValue(self, m: Any, key: Any) -> Any:
+    def getValue(self, m: CONTEXT, key: Any) -> Any:
         try:
             return self.contextType.getValue(m, key)
         except Exception as e:
@@ -889,7 +887,7 @@ class BaseFEELLib(FEELLib):
             self.logError(message, e)
             return False
 
-    def rangeValue(self, value: Range) -> Optional[Range]:
+    def rangeValue(self, value: RANGE) -> RANGE:
         try:
             return self.rangeType.rangeValue(value)
         except Exception as e:
@@ -897,7 +895,7 @@ class BaseFEELLib(FEELLib):
             self.logError(message, e)
             return None
 
-    def rangeIs(self, range1: Range, range2: Range) -> BOOLEAN:
+    def rangeIs(self, range1: RANGE, range2: RANGE) -> BOOLEAN:
         try:
             return self.rangeType.rangeIs(range1, range2)
         except Exception as e:
@@ -905,7 +903,7 @@ class BaseFEELLib(FEELLib):
             self.logError(message, e)
             return None
 
-    def rangeEqual(self, range1: Range, range2: Range) -> BOOLEAN:
+    def rangeEqual(self, range1: RANGE, range2: RANGE) -> BOOLEAN:
         try:
             return self.rangeType.rangeEqual(range1, range2)
         except Exception as e:
@@ -913,7 +911,7 @@ class BaseFEELLib(FEELLib):
             self.logError(message, e)
             return None
 
-    def rangeNotEqual(self, range1: Range, range2: Range) -> BOOLEAN:
+    def rangeNotEqual(self, range1: RANGE, range2: RANGE) -> BOOLEAN:
         try:
             return self.rangeType.rangeNotEqual(range1, range2)
         except Exception as e:
@@ -973,11 +971,11 @@ class BaseFEELLib(FEELLib):
         else:
             return list(args)
 
-    def asElement(self, list: LIST) -> Any:
-        if list is None:
+    def asElement(self, list_: LIST) -> Any:
+        if list_ is None:
             return None
-        elif len(list) == 1:
-            return list[0]
+        elif len(list_) == 1:
+            return list_[0]
         else:
             return None
 
@@ -995,14 +993,14 @@ class BaseFEELLib(FEELLib):
         else:
             return None
 
-    def rangeToListWithArgs(self, isOpenStart: bool, start: NUMBER, isOpenEnd: bool, end: NUMBER) -> LIST:
+    def rangeToListWithArgs(self, isOpenStart: bool, start: DECIMAL, isOpenEnd: bool, end: DECIMAL) -> LIST:
         if start is None or end is None:
             return []
         else:
             range_ = self.intRange(isOpenStart, start, isOpenEnd, end)
             return [x for x in range_]
 
-    def intRange(self, isOpenStart: bool, start: NUMBER, isOpenEnd: bool, end: NUMBER):
+    def intRange(self, isOpenStart: bool, start: DECIMAL, isOpenEnd: bool, end: DECIMAL):
         if start is None or end is None:
             return None
 
@@ -1026,7 +1024,7 @@ class BaseFEELLib(FEELLib):
 
         return result
 
-    def elementAt(self, list: LIST, number: NUMBER) -> Any:
+    def elementAt(self, list: LIST, number: DECIMAL) -> Any:
         if list is None:
             return None
 
@@ -1055,8 +1053,8 @@ class BaseFEELLib(FEELLib):
                     return False
             return True
 
-    def valueOf(self, number: int) -> NUMBER:
+    def valueOf(self, number: int) -> DECIMAL:
         pass
 
-    def intValue(self, number: NUMBER) -> int:
+    def intValue(self, number: DECIMAL) -> int:
         pass
