@@ -13,7 +13,7 @@
 from typing import Any, Optional
 
 from jdmn.feel.lib.BaseFEELLib import BaseFEELLib
-from jdmn.feel.lib.Types import NUMBER, STRING, BOOLEAN, DATE, TIME, DATE_TIME, DURATION, LIST
+from jdmn.feel.lib.Types import DECIMAL, STRING, BOOLEAN, DATE, TIME, DATE_TIME, DURATION, LIST, DATE_OR_DATE_TIME, TIME_OR_DATE_TIME
 from jdmn.feel.lib.type.ComparableComparator import comparable
 from jdmn.feel.lib.type.bool.DefaultBooleanLib import DefaultBooleanLib
 from jdmn.feel.lib.type.list.DefaultListLib import DefaultListLib
@@ -44,7 +44,7 @@ class BaseStandardFEELLib(BaseFEELLib):
     #
     # Conversion functions
     #
-    def number(self, literal: STRING, groupingSeparator: STRING = None, decimalSeparator: STRING = None) -> NUMBER:
+    def number(self, literal: STRING, groupingSeparator: STRING = None, decimalSeparator: STRING = None) -> DECIMAL:
         try:
             return self.numberLib.number(literal, groupingSeparator, decimalSeparator)
         except Exception as e:
@@ -68,7 +68,6 @@ class BaseStandardFEELLib(BaseFEELLib):
             self.logError(message, e)
             return None
 
-    # TODO ZoneIDs not supported in ISO 8601
     def time(self, *args) -> TIME:
         try:
             return self.dateTimeLib.time(*args)
@@ -93,7 +92,7 @@ class BaseStandardFEELLib(BaseFEELLib):
             self.logError(message, e)
             return None
 
-    def yearsAndMonthsDuration(self, from_: DATE, to: DATE) -> DURATION:
+    def yearsAndMonthsDuration(self, from_: DATE_OR_DATE_TIME, to: DATE_OR_DATE_TIME) -> DURATION:
         try:
             return self.durationLib.yearsAndMonthsDuration(from_, to)
         except Exception as e:
@@ -131,7 +130,7 @@ class BaseStandardFEELLib(BaseFEELLib):
     #
     # Numeric functions
     #
-    def decimal(self, n: NUMBER, scale: NUMBER) -> NUMBER:
+    def decimal(self, n: DECIMAL, scale: DECIMAL) -> DECIMAL:
         try:
             return self.numberLib.decimal(n, scale)
         except Exception as e:
@@ -139,7 +138,7 @@ class BaseStandardFEELLib(BaseFEELLib):
             self.logError(message, e)
             return None
 
-    def round(self, n: NUMBER, scale: NUMBER, mode: STRING) -> NUMBER:
+    def round(self, n: DECIMAL, scale: DECIMAL, mode: STRING) -> DECIMAL:
         try:
             roundingMode = NumericRoundingMode.fromName(mode)
             if roundingMode is None:
@@ -152,7 +151,7 @@ class BaseStandardFEELLib(BaseFEELLib):
             self.logError(message, e)
             return None
 
-    def roundUp(self, n: NUMBER, scale: NUMBER) -> NUMBER:
+    def roundUp(self, n: DECIMAL, scale: DECIMAL) -> DECIMAL:
         try:
             return self.numberLib.round(n, scale, NumericRoundingMode.UP)
         except Exception as e:
@@ -160,7 +159,7 @@ class BaseStandardFEELLib(BaseFEELLib):
             self.logError(message, e)
             return None
 
-    def roundDown(self, n: NUMBER, scale: NUMBER) -> NUMBER:
+    def roundDown(self, n: DECIMAL, scale: DECIMAL) -> DECIMAL:
         try:
             return self.numberLib.round(n, scale, NumericRoundingMode.DOWN)
         except Exception as e:
@@ -168,7 +167,7 @@ class BaseStandardFEELLib(BaseFEELLib):
             self.logError(message, e)
             return None
 
-    def roundHalfUp(self, n: NUMBER, scale: NUMBER) -> NUMBER:
+    def roundHalfUp(self, n: DECIMAL, scale: DECIMAL) -> DECIMAL:
         try:
             return self.numberLib.round(n, scale, NumericRoundingMode.HALF_UP)
         except Exception as e:
@@ -176,7 +175,7 @@ class BaseStandardFEELLib(BaseFEELLib):
             self.logError(message, e)
             return None
 
-    def roundHalfDown(self, n: NUMBER, scale: NUMBER) -> NUMBER:
+    def roundHalfDown(self, n: DECIMAL, scale: DECIMAL) -> DECIMAL:
         try:
             return self.numberLib.round(n, scale, NumericRoundingMode.HALF_DOWN)
         except Exception as e:
@@ -184,19 +183,19 @@ class BaseStandardFEELLib(BaseFEELLib):
             self.logError(message, e)
             return None
 
-    def floor(self, n: NUMBER, scale: NUMBER = None) -> NUMBER:
+    def floor(self, *args) -> DECIMAL:
         try:
-            return self.numberLib.floor(n, scale)
+            return self.numberLib.floor(*args)
         except Exception as e:
-            message: STRING = "floor({}, {})".format(n, scale)
+            message: STRING = "floor({})".format(*args)
             self.logError(message, e)
             return None
 
-    def ceiling(self, number: NUMBER, scale: NUMBER = None) -> NUMBER:
+    def ceiling(self, *args) -> DECIMAL:
         try:
-            return self.numberLib.ceiling(number, scale)
+            return self.numberLib.ceiling(*args)
         except Exception as e:
-            message: STRING = "ceiling({}, {})".format(number, scale)
+            message: STRING = "ceiling({})".format(*args)
             self.logError(message, e)
             return None
 
@@ -211,7 +210,7 @@ class BaseStandardFEELLib(BaseFEELLib):
             self.logError(message, e)
             return None
 
-    def intModulo(self, dividend: NUMBER, divisor: NUMBER) -> NUMBER:
+    def intModulo(self, dividend: DECIMAL, divisor: DECIMAL) -> DECIMAL:
         try:
             return self.numberLib.intModulo(dividend, divisor)
         except Exception as e:
@@ -219,7 +218,7 @@ class BaseStandardFEELLib(BaseFEELLib):
             self.logError(message, e)
             return None
 
-    def modulo(self, dividend: NUMBER, divisor: NUMBER) -> NUMBER:
+    def modulo(self, dividend: DECIMAL, divisor: DECIMAL) -> DECIMAL:
         try:
             return self.numberLib.modulo(dividend, divisor)
         except Exception as e:
@@ -227,7 +226,7 @@ class BaseStandardFEELLib(BaseFEELLib):
             self.logError(message, e)
             return None
 
-    def sqrt(self, number: NUMBER) -> NUMBER:
+    def sqrt(self, number: DECIMAL) -> DECIMAL:
         try:
             return self.numberLib.sqrt(number)
         except Exception as e:
@@ -235,7 +234,7 @@ class BaseStandardFEELLib(BaseFEELLib):
             self.logError(message, e)
             return None
 
-    def log(self, number: NUMBER) -> NUMBER:
+    def log(self, number: DECIMAL) -> DECIMAL:
         try:
             return self.numberLib.log(number)
         except Exception as e:
@@ -243,7 +242,7 @@ class BaseStandardFEELLib(BaseFEELLib):
             self.logError(message, e)
             return None
 
-    def exp(self, number: NUMBER) -> NUMBER:
+    def exp(self, number: DECIMAL) -> DECIMAL:
         try:
             return self.numberLib.exp(number)
         except Exception as e:
@@ -251,7 +250,7 @@ class BaseStandardFEELLib(BaseFEELLib):
             self.logError(message, e)
             return None
 
-    def odd(self, number: NUMBER) -> BOOLEAN:
+    def odd(self, number: DECIMAL) -> BOOLEAN:
         try:
             return self.numberLib.odd(number)
         except Exception as e:
@@ -259,7 +258,7 @@ class BaseStandardFEELLib(BaseFEELLib):
             self.logError(message, e)
             return None
 
-    def even(self, number: NUMBER) -> BOOLEAN:
+    def even(self, number: DECIMAL) -> BOOLEAN:
         try:
             return self.numberLib.even(number)
         except Exception as e:
@@ -267,7 +266,7 @@ class BaseStandardFEELLib(BaseFEELLib):
             self.logError(message, e)
             return None
 
-    def mean(self, *args) -> NUMBER:
+    def mean(self, *args) -> DECIMAL:
         try:
             return self.numberLib.mean(*args)
         except Exception as e:
@@ -302,7 +301,7 @@ class BaseStandardFEELLib(BaseFEELLib):
             self.logError(message, e)
             return None
 
-    def stringLength(self, string: STRING) -> NUMBER:
+    def stringLength(self, string: STRING) -> DECIMAL:
         try:
             return None if string is None else self.valueOf(self.stringLib.stringLength(string))
         except Exception as e:
@@ -310,7 +309,7 @@ class BaseStandardFEELLib(BaseFEELLib):
             self.logError(message, e)
             return None
 
-    def substring(self, string: STRING, startPosition: NUMBER, length: NUMBER = None) -> STRING:
+    def substring(self, string: STRING, startPosition: DECIMAL, length: DECIMAL = None) -> STRING:
         try:
             return self.stringLib.substring(string, self.numberLib.toNumber(startPosition), self.numberLib.toNumber(length))
         except Exception as e:
@@ -420,7 +419,7 @@ class BaseStandardFEELLib(BaseFEELLib):
     #
     # Date properties
     #
-    def year(self, date: DATE) -> NUMBER:
+    def year(self, date: DATE_OR_DATE_TIME) -> DECIMAL:
         try:
             return self.valueOf(self.dateTimeLib.year(date))
         except Exception as e:
@@ -428,7 +427,7 @@ class BaseStandardFEELLib(BaseFEELLib):
             self.logError(message, e)
             return None
 
-    def month(self, date: DATE) -> NUMBER:
+    def month(self, date: DATE_OR_DATE_TIME) -> DECIMAL:
         try:
             return self.valueOf(self.dateTimeLib.month(date))
         except Exception as e:
@@ -436,7 +435,7 @@ class BaseStandardFEELLib(BaseFEELLib):
             self.logError(message, e)
             return None
 
-    def day(self, date: DATE) -> NUMBER:
+    def day(self, date: DATE_OR_DATE_TIME) -> DECIMAL:
         try:
             return self.valueOf(self.dateTimeLib.day(date))
         except Exception as e:
@@ -444,7 +443,7 @@ class BaseStandardFEELLib(BaseFEELLib):
             self.logError(message, e)
             return None
 
-    def weekday(self, date: DATE) -> NUMBER:
+    def weekday(self, date: DATE_OR_DATE_TIME) -> DECIMAL:
         try:
             return self.valueOf(self.dateTimeLib.weekday(date))
         except Exception as e:
@@ -455,7 +454,7 @@ class BaseStandardFEELLib(BaseFEELLib):
     #
     # Time properties
     #
-    def hour(self, time: TIME) -> NUMBER:
+    def hour(self, time: TIME_OR_DATE_TIME) -> DECIMAL:
         try:
             return self.valueOf(self.dateTimeLib.hour(time))
         except Exception as e:
@@ -463,7 +462,7 @@ class BaseStandardFEELLib(BaseFEELLib):
             self.logError(message, e)
             return None
 
-    def minute(self, time: TIME) -> NUMBER:
+    def minute(self, time: TIME_OR_DATE_TIME) -> DECIMAL:
         try:
             return self.valueOf(self.dateTimeLib.minute(time))
         except Exception as e:
@@ -471,7 +470,7 @@ class BaseStandardFEELLib(BaseFEELLib):
             self.logError(message, e)
             return None
 
-    def second(self, time: TIME) -> NUMBER:
+    def second(self, time: TIME_OR_DATE_TIME) -> DECIMAL:
         try:
             return self.valueOf(self.dateTimeLib.second(time))
         except Exception as e:
@@ -479,7 +478,7 @@ class BaseStandardFEELLib(BaseFEELLib):
             self.logError(message, e)
             return None
 
-    def timeOffset(self, time: TIME) -> DURATION:
+    def timeOffset(self, time: TIME_OR_DATE_TIME) -> DURATION:
         try:
             return self.dateTimeLib.timeOffset(time)
         except Exception as e:
@@ -487,7 +486,7 @@ class BaseStandardFEELLib(BaseFEELLib):
             self.logError(message, e)
             return None
 
-    def timezone(self, time: TIME) -> STRING:
+    def timezone(self, time: TIME_OR_DATE_TIME) -> STRING:
         try:
             return self.dateTimeLib.timezone(time)
         except Exception as e:
@@ -499,7 +498,7 @@ class BaseStandardFEELLib(BaseFEELLib):
     # Duration properties
     #
 
-    def years(self, duration: DURATION) -> NUMBER:
+    def years(self, duration: DURATION) -> DECIMAL:
         try:
             return self.valueOf(self.durationLib.years(duration))
         except Exception as e:
@@ -507,7 +506,7 @@ class BaseStandardFEELLib(BaseFEELLib):
             self.logError(message, e)
             return None
 
-    def months(self, duration: DURATION) -> NUMBER:
+    def months(self, duration: DURATION) -> DECIMAL:
         try:
             return self.valueOf(self.durationLib.months(duration))
         except Exception as e:
@@ -515,7 +514,7 @@ class BaseStandardFEELLib(BaseFEELLib):
             self.logError(message, e)
             return None
 
-    def days(self, duration: DURATION) -> NUMBER:
+    def days(self, duration: DURATION) -> DECIMAL:
         try:
             return self.valueOf(self.durationLib.days(duration))
         except Exception as e:
@@ -523,7 +522,7 @@ class BaseStandardFEELLib(BaseFEELLib):
             self.logError(message, e)
             return None
 
-    def hours(self, duration: DURATION) -> NUMBER:
+    def hours(self, duration: DURATION) -> DECIMAL:
         try:
             return self.valueOf(self.durationLib.hours(duration))
         except Exception as e:
@@ -531,7 +530,7 @@ class BaseStandardFEELLib(BaseFEELLib):
             self.logError(message, e)
             return None
 
-    def minutes(self, duration: DURATION) -> NUMBER:
+    def minutes(self, duration: DURATION) -> DECIMAL:
         try:
             return self.valueOf(self.durationLib.minutes(duration))
         except Exception as e:
@@ -539,7 +538,7 @@ class BaseStandardFEELLib(BaseFEELLib):
             self.logError(message, e)
             return None
 
-    def seconds(self, duration: DURATION) -> NUMBER:
+    def seconds(self, duration: DURATION) -> DECIMAL:
         try:
             return self.valueOf(self.durationLib.seconds(duration))
         except Exception as e:
@@ -553,7 +552,7 @@ class BaseStandardFEELLib(BaseFEELLib):
 
     def is_(self, value1: Any, value2: Any) -> BOOLEAN:
         try:
-            if (value1 is None or value2 is None):
+            if value1 is None or value2 is None:
                 return value1 == value2
             elif type(value1) != type(value2):
                 # Different kind
@@ -591,7 +590,7 @@ class BaseStandardFEELLib(BaseFEELLib):
     # Temporal functions
     #
 
-    def dayOfYear(self, date: DATE) -> NUMBER:
+    def dayOfYear(self, date: DATE) -> DECIMAL:
         try:
             return self.valueOf(self.dateTimeLib.dayOfYear(date))
         except Exception as e:
@@ -607,7 +606,7 @@ class BaseStandardFEELLib(BaseFEELLib):
             self.logError(message, e)
             return None
 
-    def weekOfYear(self, date: DATE) -> NUMBER:
+    def weekOfYear(self, date: DATE) -> DECIMAL:
         try:
             return self.valueOf(self.dateTimeLib.weekOfYear(date))
         except Exception as e:
@@ -643,7 +642,7 @@ class BaseStandardFEELLib(BaseFEELLib):
             self.logError(message, e)
             return None
 
-    def count(self, list: LIST) -> NUMBER:
+    def count(self, list: LIST) -> DECIMAL:
         try:
             return self.numberLib.count(list)
         except Exception as e:
@@ -675,7 +674,7 @@ class BaseStandardFEELLib(BaseFEELLib):
             self.logError(message, e)
             return None
 
-    def sublist(self, list: LIST, startPosition: NUMBER, length: NUMBER = None) -> LIST:
+    def sublist(self, list: LIST, startPosition: DECIMAL, length: DECIMAL = None) -> LIST:
         try:
             return self.listLib.sublist(list, self.intValue(startPosition), self.intValue(length))
         except Exception as e:
@@ -691,7 +690,7 @@ class BaseStandardFEELLib(BaseFEELLib):
             self.logError(message, e)
             return None
 
-    def insertBefore(self, list: LIST, position: NUMBER, newItem: Any) -> LIST:
+    def insertBefore(self, list: LIST, position: DECIMAL, newItem: Any) -> LIST:
         try:
             return self.listLib.insertBefore(list, self.intValue(position), newItem)
         except Exception as e:
@@ -747,7 +746,7 @@ class BaseStandardFEELLib(BaseFEELLib):
             self.logError(message, e)
             return None
 
-    def product(self, *args) -> NUMBER:
+    def product(self, *args) -> DECIMAL:
         try:
             return self.numberLib.product(*args)
         except Exception as e:
@@ -755,7 +754,7 @@ class BaseStandardFEELLib(BaseFEELLib):
             self.logError(message, e)
             return None
 
-    def median(self, *args) -> NUMBER:
+    def median(self, *args) -> DECIMAL:
         try:
             return self.numberLib.median(*args)
         except Exception as e:
@@ -763,7 +762,7 @@ class BaseStandardFEELLib(BaseFEELLib):
             self.logError(message, e)
             return None
 
-    def stddev(self, *args) -> NUMBER:
+    def stddev(self, *args) -> DECIMAL:
         try:
             return self.numberLib.stddev(*args)
         except Exception as e:
