@@ -598,6 +598,7 @@ class BaseStandardFEELLibTest(BaseFEELLibTest):
         self.assertIsNone(self.getLib().replace(None, "(ab)|(a)", "[1=$1][2=$2]"))
         self.assertIsNone(self.getLib().replace("abcd", None, "[1=$1][2=$2]"))
         self.assertIsNone(self.getLib().replace("abcd", "(ab)|(a)", None))
+        self.assertIsNone(self.getLib().replace("abcd", "(ab)|(a)", "$"))
 
         self.assertEqual("[1=ab][2=]cd", self.getLib().replace("abcd", "(ab)|(a)", "[1=$1][2=$2]"))
 
@@ -621,6 +622,7 @@ class BaseStandardFEELLibTest(BaseFEELLibTest):
         self.assertTrue(self.getLib().matches("abracadabra", "bra"))
         self.assertTrue(self.getLib().matches("abracadabra", "^a.*a$"))
         self.assertFalse(self.getLib().matches("abracadabra", "^bra"))
+        self.assertTrue(self.getLib().matches("abracadabra", "^abra"))
 
         input: STRING = "Kaum hat dies der Hahn gesehen,\n" \
                         "Fangt er auch schon an zu krahen:\n" \
